#include <qobjectlist.h>
#include <qgrid.h>
#include <qcombobox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qslider.h>
#include <qspinbox.h>
#include <qtextedit.h>

#include <krootpixmap.h>
#include <klocale.h>

#include "transparencydemo.h"

TransparencyDemo::TransparencyDemo( QWidget *parent, const char *name )
    : QVBox( parent, name)
{
    setMargin( 6 );
    setSpacing( 4 );
    resize( 600, 550 );

    addHeading( i18n("KRootPixmap Example"), this );

    addSection( i18n("Demo Form"), this );
    addForm( this );

    addSection( i18n("Demo View"), this );
    addView( this );

    makeTransparent( this );
}

TransparencyDemo::~TransparencyDemo()
{
}

void TransparencyDemo::makeTransparent( QWidget *w )
{
    KRootPixmap *rp = new KRootPixmap( w );
    rp->start();

    QObjectList *l = w->queryList( "QWidget" );
    QObjectListIt it( *l );

    for ( QObject *obj = it.current() ; it.current() ; ++it, obj = it.current() ) {
	QWidget *w = static_cast<QWidget *>( obj );

	KRootPixmap *rp = new KRootPixmap( w );
	rp->start();
    }
    delete l;
}

//
// Example views
//

QWidget *TransparencyDemo::addHeading( const QString &text, QWidget *w )
{
    QLabel *heading = new QLabel( text, w );
    heading->setSizePolicy( QSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed ) );
    heading->setMargin( 6 );

    heading->setAlignment( AlignCenter );
    QFont f = heading->font();
    f.setPointSize( 24 );
    f.setBold( true );
    heading->setFont( f );

    heading->setFrameStyle( QFrame::Panel|QFrame::Plain );
    heading->setLineWidth( 3 );

    return heading;
}

QWidget *TransparencyDemo::addSection( const QString &text, QWidget *w )
{
    QLabel *heading = new QLabel( text, w );
    heading->setSizePolicy( QSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed ) );

    heading->setAlignment( AlignVCenter|AlignLeft );
    QFont f = heading->font();
    f.setPointSize( 18 );
    f.setBold( true );
    heading->setFont( f );

    heading->setFrameStyle( QFrame::Panel|QFrame::Plain );
    heading->setLineWidth( 2 );

    return heading;
}

QWidget *TransparencyDemo::addForm( QWidget *w )
{
    QGrid *grid = new QGrid( 2, w );
    grid->setSizePolicy( QSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Minimum ) );
    grid->setSpacing( 4 );
    grid->setMargin( 6 );

    new QLabel( "Slider:", grid );
    new QSlider( Horizontal, grid );

    new QLabel( "Line Edit:", grid );
    new QLineEdit( "value", grid );

    new QLabel( "Spin Box:", grid );
    new QSpinBox( grid );

    new QLabel( "Choice:", grid );
    new QComboBox( "Combo", grid );

    return grid;
}

QWidget *TransparencyDemo::addView( QWidget *w )
{
    QTextEdit *text = new QTextEdit( w );
    text->setSizePolicy( QSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Expanding ) );
    text->setText( childInfo( w ) );

    return text;
}

QString TransparencyDemo::childInfo( QWidget *w )
{
    QObjectListIt it( *(w->queryList( "QWidget" )) );
    QString tree;

    for ( QObject *obj = it.current() ; it.current() ; ++it, obj = it.current() ) {
	tree.append( QString("%1 (%2)\n").arg( obj->name() ).arg( obj->className() ) );
    }
	
    return tree;
}
